/*****************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   e-mail: bowkenken@users.sourceforge.jp
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: config-dos.h,v 1.10 2008/09/16 07:42:41 bowkenken Exp $
*****************************************************************/

#ifndef	CONFIG_DOS_H
#define	CONFIG_DOS_H

/*#define	HAVE_CONFIG_H	0*/
#define	HAVE_STDLIB_H	1
#define	HAVE_STDDEF_H	1
#define	HAVE_STDIO_H	1
#define	HAVE_STDARG_H	1
#define	HAVE_LIMITS_H	1
#define	HAVE_STRING_H	1
/*#define	HAVE_STRINGS_H	0*/
#define	HAVE_CTYPE_H	1
#define	HAVE_TIME_H	1
#define	HAVE_MATH_H	1
#define	HAVE_DIRECT_H	1
#define	HAVE_SYS_STAT_H	1
/*#define	HAVE_UNISTD_H	0*/

/*#define	HAVE_MKDIR	0*/
/*#define	HAVE_SLEEP	0*/

#define	VERSION	"3.3.4"

#endif	/* CONFIG_DOS_H */
